Author: hwright
Date: Tue Jul 13 10:57:24 2010
New Revision: 963676

URL: http://svn.apache.org/viewvc?rev=963676&view=rev
Log:
* subversion/libsvn_wc/copy.c
  (copy_versioned_dir): Update a deprecated API use.

Modified:
    subversion/trunk/subversion/libsvn_wc/copy.c

Modified: subversion/trunk/subversion/libsvn_wc/copy.c
URL: 
http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/copy.c?rev=963676&r1=963675&r2=963676&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/copy.c (original)
+++ subversion/trunk/subversion/libsvn_wc/copy.c Tue Jul 13 10:57:24 2010
@@ -482,8 +482,11 @@ copy_versioned_dir(svn_wc__db_t *db,
     }
 
   if (kind == svn_node_dir)
-    /* All children, versioned and unversioned */
-    SVN_ERR(svn_io_get_dirents2(&children, src_abspath, scratch_pool));
+    /* All children, versioned and unversioned.  We're only interested in the
+       names of the children, so we can pass TRUE as the only_check_type
+       param. */
+    SVN_ERR(svn_io_get_dirents3(&children, src_abspath, TRUE,
+                                scratch_pool, scratch_pool));
 
   /* Copy all the versioned children */
   SVN_ERR(svn_wc__db_read_children(&versioned_children, db, src_abspath,


Reply via email to